#ifndef _INTERFACE_
#define _INTERFACE_

#include <map>
#include <sys/types.h>
#include <dirent.h>
#include <errno.h>
#include <vector>
#include <string>
#include <iostream>
#include <gtk/gtk.h>

#include <stdlib.h>
#include <gio/gio.h>

#include "gloobus-preview-defines.h"
#include "config.h"

using namespace std;

class interface
{
	protected:		
	string			m_filename;
	string			m_filetype;
	string			m_uri;
	GFile * 		m_gfile;

	public:

	// ======== VIRTUAL FUNCTIONS ======= //
	// These function need to be implemented by plugins or its interface!!
	virtual int		get_width 	( void ) = 0;
	virtual int		get_height	( void ) = 0;
	virtual void	load		( void ) = 0;
	virtual void	draw		( GtkContainer * container ) = 0;
	virtual void	end			( void ) = 0;
	//virtual void	draw_fullscreen (GtkContainer * container ) = 0;
		
	void			set_filename	 		( string filename );
	void			set_file_info	 		( void );
	string			get_file_size	 		( string filename );
	double			get_file_size	 		( string filename , bool number);
	double			get_directory_size		( string filename );
	string			get_file_info_string 	( void );
	string			get_safe_type	 		( bool replace_slash );				//Mime Type
	int  			get_screen_width 		( void );
	int  			get_screen_height		( void );
	
	void 			draw_file_info			( GtkContainer * container );
	void 			draw_properties			( GtkContainer * container , string text , int x, int y);
	GdkPixbuf *		get_icon				( void );


	

};

// ================================================================================ //
struct plugin_filetype
{
		string name;			//Plugin Name
		string filetype;		//Filetype that plugins reads
		string type;			//If image, document, music, video... It will be declared in the interface
		int priority;			//Priority of use this plugin before another
};


typedef int getVersion_t();									//GET VERSION FUNCTION, ALL PLUGINS MUST HAVE IT
extern vector<plugin_filetype> pluginVector;				//VECTOR TO STORE WICH FILETYPE READ EACH PLUGIN

#endif
